**Example 1: 镜像仓库查询镜像统计信息**



Input: 

```
tccli tcss DescribeAssetImageRegistrySummary --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "5247d905-bf3c-41b4-9d6f-f93a008d9efb"
    }
}
```

